@@ -1,6 +1,7 @@
 import pandas as pd
+from sklearn.base import BaseEstimator
+from sklearn.base import TransformerMixin
 from workalendar.registry import registry
-from sklearn.base import BaseEstimator, TransformerMixin
 
 
 class HolidayTransformer(TransformerMixin, BaseEstimator):
