@@ -348,8 +348,6 @@ def get_gridsearch(
                 "model__trend": ["add"],
                 "model__seasonal": [None, "add"],
                 "model__damped_trend": [True, False],
-                "model__use_boxcox": [True, False],
-                "model__use_basinhopping": [False],
             }
         )
 
@@ -366,8 +364,6 @@ def get_gridsearch(
                 "model__trend": ["add"],
                 "model__seasonal": ["mul"],
                 "model__damped_trend": [True, False],
-                "model__use_boxcox": [False],
-                "model__use_basinhopping": [False],
             }
         )
 
@@ -384,8 +380,6 @@ def get_gridsearch(
                 "model__trend": [None],
                 "model__seasonal": [None, "add", "mul"],
                 "model__damped_trend": [False],
-                "model__use_boxcox": [False],
-                "model__use_basinhopping": [False],
             }
         )
 
